==> kdepim-3.2.3.tar.bz2: kdepim-3.2.3/kontact/plugins/korganizer/summarywidget.h <==
/*
    This file is part of Kontact.
    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef SUMMARYWIDGET_H
#define SUMMARYWIDGET_H

#include <qptrlist.h>
#include <qwidget.h>

#include <libkcal/calendarresources.h>

#include "summary.h"

namespace Kontact {
  class Plugin;
  class Core;
}

class QGridLayout;
class QLabel;

class SummaryWidget : public Kontact::Summary
{
  Q_OBJECT

  public:
    SummaryWidget( Kontact::Plugin *plugin, QWidget *parent,
                   const char *name = 0 );

    int summaryHeight() const { return 3; }

  private slots:
    void updateView();
    void selectEvent( const QString &uid );

  private:
    Kontact::Plugin *mPlugin;
    QVBoxLayout *mMainLayout;
    QGridLayout *mLayout;

    QPtrList<QLabel> mLabels;
    KCal::CalendarResources *mCalendar;
};

#endif

==> kdepim-3.5.2.tar.bz2: kdepim-3.5.2/kontact/plugins/korganizer/summarywidget.h <==
/*
    This file is part of Kontact.
    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef SUMMARYWIDGET_H
#define SUMMARYWIDGET_H

#include <qptrlist.h>
#include <qwidget.h>

#include <libkcal/calendarresources.h>

#include "summary.h"

class QGridLayout;
class QLabel;

class KOrganizerPlugin;

class SummaryWidget : public Kontact::Summary
{
  Q_OBJECT

  public:
    SummaryWidget( KOrganizerPlugin *plugin, QWidget *parent,
                   const char *name = 0 );
    ~SummaryWidget();

    int summaryHeight() const { return 3; }
    QStringList configModules() const;
  public slots:
    void updateSummary( bool force = false ) { Q_UNUSED( force ); updateView(); }

  protected:
    virtual bool eventFilter( QObject *obj, QEvent* e );

  private slots:
    void updateView();
    void selectEvent( const QString &uid );

  private:
    KOrganizerPlugin *mPlugin;
    QGridLayout *mLayout;

    QPtrList<QLabel> mLabels;
    KCal::CalendarResources *mCalendar;
};

#endif
